#
# spec file for package qwt6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global qwt6_flavor qt5%{nil}
%if "%{qwt6_flavor}" == ""
ExclusiveArch:  do_not_build
%endif
%if "%{qwt6_flavor}" == "qt6"
%define qt6 1
%define pkg_suffix -qt6
%define qt_descr Qt6
%endif
%if "%{qwt6_flavor}" == "qt5"
%define qt5 1
%define pkg_suffix -qt5
%define qt_descr Qt5
%endif

%define sover   6_3
%define mver    6
%define bver    6.3
Name:           qwt6%{?pkg_suffix}
Version:        6.3.0
Release:        1.3
Summary:        %{qt_descr} Widgets for Technical Applications
License:        SUSE-QWT-1.0
Group:          Development/Libraries/C and C++
URL:            https://qwt.sourceforge.io
Source:         https://sourceforge.net/projects/qwt/files/qwt/%{version}/qwt-%{version}.tar.bz2
Source99:       qwt6-rpmlintrc
# PATCH-FIX-OPENSUSE to prevent 'ERROR: RPATH "/usr/local/qwt-6.1.0/lib" on
# /usr/lib(64)/qt(4,5)/plugins/designer/libqwt_designer_plugin.so is not allowed'.
Patch0:         qwt-6.1.3-rpath.patch
# PATCH-FIX-OPENSUSE mkspecs.patch -- Use established settings for the .pc files
Patch2:         qwt-6.1.4-mkspecs.patch
# PATCH-FIX-OPENSUSE qwt-6.2.0-qt6-pkgconfig.patch -- require correct libraries in Qt6 pkgconfig
Patch3:         qwt-6.2.0-qt6-pkgconfig.patch
#
# PATCH-FIX-OPENSUSE qwt-6.2.0-qt6-libsuffix.patch -- change SONAMEs to avoid conflicts
Patch4:         qwt-6.2.0-qt6-libsuffix.patch
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
%if 0%{?qt5}
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
%endif
%if 0%{?qt6}
BuildRequires:  pkgconfig(Qt6Concurrent)
BuildRequires:  pkgconfig(Qt6Designer)
BuildRequires:  pkgconfig(Qt6OpenGL)
BuildRequires:  pkgconfig(Qt6PrintSupport)
BuildRequires:  pkgconfig(Qt6Svg)
%endif
BuildRequires:  pkgconfig(libpng)

%description
The Qwt(%{qt_descr}) library contains GUI Components and utility classes which are
primarily useful for programs with a technical background. Beside a 2D
plot widget it provides scales, sliders, dials, compasses, thermometers,
wheels and knobs to control or display values, arrays, or ranges of type
double.

%package -n libqwt%{mver}-%{qwt6_flavor}-%{sover}
Summary:        Shared library for %{qt_descr} Widgets for Technical Applications
Group:          System/Libraries

%description -n libqwt%{mver}-%{qwt6_flavor}-%{sover}
This package contains the shared library to run Technical Applications
developed with/for Qwt(Qt5).

%package devel
Summary:        Include headers and Qt Designer plugin for Qwt(Qt5)
Group:          Development/Libraries/C and C++
Requires:       libqwt%{mver}-%{qwt6_flavor}-%{sover} = %{version}
Requires:       freetype2-devel
Requires:       gcc-c++
%if 0%{?qt5}
Requires:       pkgconfig(Qt5Concurrent)
Requires:       pkgconfig(Qt5OpenGL)
Requires:       pkgconfig(Qt5PrintSupport)
Requires:       pkgconfig(Qt5Svg)
Requires:       pkgconfig(Qt5Widgets)
%endif
%if 0%{?qt6}
Requires:       pkgconfig(Qt6Concurrent)
Requires:       pkgconfig(Qt6OpenGL)
Requires:       pkgconfig(Qt6PrintSupport)
Requires:       pkgconfig(Qt6Svg)
Requires:       pkgconfig(Qt6Widgets)
%endif
Requires:       pkgconfig(libpng)
Recommends:     %{name}-designer
Recommends:     %{name}-devel-doc
Recommends:     %{name}-examples
%if 0%{?qt5}
Conflicts:      otherproviders(qwt-qt5-devel)
Conflicts:      qwt-devel
Provides:       qwt-qt5-devel = %{version}
%endif

%description devel
This package contains the header files of Qwt and its Qt designer plugin
in order to create Qt applications using the Qwt(%{qt_descr}) widgets.

%package examples
Summary:        Example programs using Qwt(%{qt_descr})
License:        SUSE-QWT-1.0 or BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description examples
This package contains example programs demonstrating the Qwt(%{qt_descr}) widgets.

%package designer
Summary:        Plugin for the %{qt_descr} Interface designer
Group:          Development/Tools/GUI Builders
Requires:       %{name}-devel = %{version}
%if 0%{?qt5}
Conflicts:      otherproviders(qwt-qt5-designer)
Provides:       qwt-qt5-designer = %{version}
%endif

%description designer
The %{name}-designer package contains the plugin for the Qt5 User Interface
designer tool.

%package devel-doc
Summary:        Development documentation for Qwt(%{qt_descr})
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
BuildArch:      noarch

%description devel-doc
This package contains the development documentation of the Qwt(%{qt_descr}) widgets
as is it created by doxygen.

%prep
%autosetup -p1 -n qwt-%{version}

%build
mkdir build
pushd build
%if 0%{?qt5}
%qmake5 ..
%endif
%if 0%{?qt6}
%qmake6 ..
%endif
%make_jobs
popd

%install
pushd build
%if 0%{?qt5}
%qmake5_install
%endif
%if 0%{?qt6}
%qmake6_install
%endif
popd
# nothing references this
%if 0%{?qt5}
rm -f "%{buildroot}/%{_libqt5_libdir}/libqwt-%{qwt6_flavor}.so.6"
%endif
%if 0%{?qt6}
rm -f "%{buildroot}/%{_qt6_libdir}/libqwt-%{qwt6_flavor}.so.6"
%endif

# Qwt base examples
%if 0%{?qt5}
mkdir -p %{buildroot}%{%_libqt5_docdir}/qwt6
mkdir -p %{buildroot}%{_libqt5_examplesdir}/qwt6
cp -r examples %{buildroot}%{_libqt5_docdir}/qwt6/examples
cp -r build/examples/bin %{buildroot}%{_libqt5_examplesdir}/qwt6
%endif
%if 0%{?qt6}
mkdir -p %{buildroot}%{%_qt6_docdir}/qwt6
mkdir -p %{buildroot}%{_qt6_examplesdir}/qwt6
cp -r examples %{buildroot}%{_qt6_docdir}/qwt6/examples
cp -r build/examples/bin %{buildroot}%{_qt6_examplesdir}/qwt6
%endif

%fdupes %{buildroot}%{_prefix}

%post -n libqwt%{mver}-%{qwt6_flavor}-%{sover} -p /sbin/ldconfig
%postun -n libqwt%{mver}-%{qwt6_flavor}-%{sover} -p /sbin/ldconfig

%files -n libqwt%{mver}-%{qwt6_flavor}-%{sover}
%license COPYING
%if 0%{?qt5}
%{_libqt5_libdir}/libqwt-%{qwt6_flavor}.so.%{bver}*
%endif
%if 0%{?qt6}
%{_qt6_libdir}/libqwt-%{qwt6_flavor}.so.%{bver}*
%endif

%files designer
%if 0%{?qt5}
%dir %{_libqt5_plugindir}/designer/
%{_libqt5_plugindir}/designer/*.so
%endif
%if 0%{?qt6}
%dir %{_qt6_pluginsdir}/designer/
%{_qt6_pluginsdir}/designer/*.so
%endif

%files devel
%doc README
%if 0%{?qt5}
%{_libqt5_libdir}/libqwt-%{qwt6_flavor}.so
%{_libqt5_libdir}/pkgconfig/Qt5Qwt6.pc
%{_libqt5_archdatadir}/mkspecs/features/
%dir %{_libqt5_includedir}/qwt6
%{_libqt5_includedir}/qwt6/*
%endif
%if 0%{?qt6}
%{_qt6_libdir}/libqwt-%{qwt6_flavor}.so
%{_qt6_libdir}/pkgconfig/%{qt_descr}Qwt6.pc
%{_qt6_archdatadir}/mkspecs/features/
%dir %{_qt6_includedir}/qwt6
%{_qt6_includedir}/qwt6/*
%endif

%files examples
%if 0%{?qt5}
%{_libqt5_examplesdir}/
%endif
%if 0%{?qt6}
%{_qt6_examplesdir}/
%endif

%files devel-doc
%if 0%{?qt5}
%doc %{_libqt5_docdir}/
%endif
%if 0%{?qt6}
%doc %{_qt6_docdir}/
%endif

%changelog
* Wed May  8 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.3.0
  * QwtPainter::polylineSplitting has been reenabled.
    Unfortunately the Qt raster paint engine still has serious
    performance issues with rendering long polylines.
  * QwtPlotCurve::adjacentPoint for monotonic curves: using a
    binary search algo
  * QwtPlotCurve::interpolatedValueAt for monotonic curves:
    using a binary search algo
  * QwtSeriesData
    + wrong inheritances fixed
    + firstSample, lastSample added
  * QwtPlotIntervalCurve::TubeAsLines mode added. A performance
    optimization for rendering huge datasets.
  * Bugfixes/Adjustments - often needed because of new Qt
    developments
- Refreshed qwt-6.1.4-mkspecs.patch
* Fri Apr 28 2023 Luigi Baldoni <aloisio@gmx.com>
- Fixes boo#1210931
- Add _multibuild to support Qt6
- Add qwt-6.2.0-qt6-pkgconfig.patch and
  qwt-6.2.0-qt6-libsuffix.patch (courtesy of Fedora)
  and qwt6-rpmlintrc
- Man pages are now installed in the flavored doc dir as per
  upstream default
* Tue Jul 27 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Rollback previous changes.
- Moved *.so.? & *.so.?.? to the devel subpackage.
- Added BSD-3-Clause for examples subpackage (6.2.0 changes).
* Wed Jul 21 2021 Luigi Baldoni <aloisio@gmx.com>
- Obsolete previous library version
* Tue Jul 20 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0 (boo#1187996)
  * MathML text renderer removed
  * Class Includes added
  * BSD License for examples
  * Spline interpolation
  * New plot items
- Check the installed CHANGES-6.2 file for the complete list
  of changes.
- Drop qwt-6.1.3-pkgconfig.patch. No longer needed
- Rebase qwt-6.1.4-mkspecs.patch
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.6
  * QwtPlotLayout::activate: avoid compiler issues with Qt 5.15
  * QwtPointPolar: missing copy constructor added
- Update URL
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.5:
  * Avoid using some of the deprecated Qt APIs
  * Missing includes of QPainterPath ( Qt 5.15 ) added
  * QwtPlotSpectroCurve: missing public inheritance
  * QwtPlotTradingCurve: missing public inheritance
  * QwtLinearColorMap: handling of alpha values in color stops fixed
  * QwtPlotRasterItem: Fixed missing color table initialization for
    QImage::Format_Indexed8
  * QwtScaleWidget: missing QEvent::LayoutRequest added
  * QwtSetSample: bound rectangle fixed for empty sets
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix build with recent libqt5-qttools packages.
* Wed Jun  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Fixed conflict with Qwt 5.
* Fri May 24 2019 Luigi Baldoni <aloisio@gmx.com>
- Fix requires for -devel package
* Wed May 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Build against Qt5 by default
- Dropped qwt-qt5.patch
* Fri Apr 19 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.4
  * All widgets ( including plot canvas )
    + missing initialization of the background color hint, when
    drawing a styled focus rectangle
    + devicePixelRatio handling adjusted, QT_SCALE_FACTOR supported
  * Maintenance
    + deprecated QString::null replaced by QString()
    + making clang-tidy/clazy and friends happier
    + compiler warnings with newer Qt versions fixed
  * PyQt-Qwt
    + specific defines added
  * QwtPointMapper
    + being multithreaded when possible
  * QwtPlotRenderer
    + using QPdfWriter instead of QPrinter, when possible
  * Build system
    + auto-disable building the designer plugin, when the
    corresponding Qt installation was not build with designer
    support
  * Bug fixes
    + font resolving when using widget fonts for rendering
    to a different paint device.
    + QwtPlotDirectPainter::CopyBackingStore: bad offset (
    subtracting the canvas frame ), when flushing the updated
    backing store fixed
    + QwtAbstractSlider::stepAlignment fixed, when the value is
    exactly the upperBound, but no tick position
    + Missing right/bottom pixel added for QwtColumnSymbol::NoFrame
    + QwtWeedingCurveFitter::fitCurve fixed when being called with
    no points
    + missing updates added for QwtLegend::setMaxColumns,
    QwtScaleWidget::setLayoutFlag
    + QwtPlotCurve::drawSteps: polygon clipping fixed by adding
    an extra pixel to the clip rectangle
    + QwtPlotItem::ScaleInterest enabled for all constructors of
    QwtPlotSeriesItem
    + QwtPlotMarker::boundingRect fixed for HLine/VLine
    + QwtPlotIntervalCurve/QwtPlotTradingCurve::boundingRect
    fixed
- Refreshed qwt-6.1.3-mkspecs.patch as qwt-6.1.4-mkspecs.patch
* Sat Aug  5 2017 aloisio@gmx.com
- Fixed manpages conflict with qwt5
* Wed Jul 26 2017 aloisio@gmx.com
- Remove _tmp manpages and rename the existing one to -qt5
  pattern to avoid conflict with the qt4 package
- Dropped pre_checkin.sh
* Tue Jul 25 2017 aloisio@gmx.com
- Remove _multibuild prior to Factory submission
* Tue May 30 2017 aloisio@gmx.com
- Build qwt6-qt5 as separate package
  * add qwt6-qt5.spec
  * add qwt6-qt5.changes
  * add qwt-qt5.patch
  (thanks to awissu and other contributors of the KDE:Qt5 package)
- Refreshed qwt-rpath.patch as qwt-6.1.3-rpath.patch
- Create and install pc files for pkg-config:
  * add qwt-6.1.3-pkgconfig.patch
- Use mkspecs directory
  * add qwt-6.1.3-mkspecs.patch
- Use sover macro
- Build the examples modules
- Renamed the libqwt6 package as libqwt-qt%%%%sover
- Use license macro on openSUSE >= 42.2
- Add man page
- Added pre_checkin.sh to keep .changes files in sync
- Spec cleanup
* Thu Sep 29 2016 aloisio@gmx.com
- Update to version 6.1.3
  * QwtPlotMagnifier, QwtPlotZoomer: handling of non linear
    transformations ( f.e logarithmic )
  * Date/Time scales fixed
    QwtDate::ceil(), QwtDate::weekNumber(), QwtDate::utcOffset()
    QwtDateScaleEngine fixed when aligning to months
  * QwtPlotLayout: layout bug for legends witdh visisble
    scrollbars fixed
  * Plot items
    hiding QwtPlotLegendItem without entries
    QwtPlotShapeItem render code fixed
  * QwtPlotGLCanvas
    slightly improved, nevertheless better use Qwt 6.2 when being
    interested in OpenGL
  * Other
    QwtGraphic boundingRect updates fixed
    QwtSyntheticPointData::x() fixed
    QwtLogScaleEngine::divideScale ignoring stepSize parameter
    for ranges below one "decade"
    QwtPlotAbstractBarChart::getCanvasMarginHint fixed
- Fixed source URL
* Wed Feb  4 2015 dap.darkness@gmail.com
- Update to Qwt 6.1.2
  * fixes at QwtPlot, color maps, controls and scales.
- Removed Mandriva support.
- Renamed qwt-6.1.0-rpath.patch to qwt-rpath.patch
  because upstream doesn't want merge it. Updated.
* Mon Aug 12 2013 tittiatcoke@gmail.com
- qwt6-designer is now conflicting with qwt-designer.
* Fri Aug  9 2013 dap.darkness@gmail.com
- Update to Qwt 6.1.0
  * New plot items
  * Scales beyond linear and logarithmic transformations
  * Datetime scales
  * Redesign of the dial and meter widgets
  * Basic support for an OpenGL plot canvas
  * A new system for plot legends
  * Off-screen paint device for vector graphics
  * Changes and improvements to several classes
- Added qwt-6.1.0-rpath.patch to prevent
  https://sourceforge.net/p/qwt/bugs/191
- Qmake debug info stripping was disabled.
* Mon Jan 28 2013 koprok@nand.bg
- Update to Qwt 6.0.2
  * qwtfunctions.pri added
  * QwtPlotDict::detachItems fixed
  * QwtWeedingCurveFitter::fitCurve performance improvements
  * QwtDynGridLayout fixed for non widget items
  * QwtInterval: avoid annoying compiler warning
  * Autoscaling of curves without points fixed
  * QwtPlotDirectPainter::drawSeries bad translation removed
  * QwtPlotIntervalCurve: drawing of symbols fixed
  * QwtPlotlayout: minor layout bufs fixed
  * Usage of QwtPlotRasterItem::pixelHint fixed
  * QwtPlotRenderer: several minor fixes
  * QwtRasterData: CONREC algorithm fixed
  * QwtThermo: layout code fixed
  * QwtThermo: memory leak fixed
  * QwtMmlDocument: compiler issues
  * Logarithmic autoscaler fixed for intervals close below a decade
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Thu Mar 29 2012 cfarrell@suse.com
- license update: SUSE-QWT-1.0
  Added to spreadsheet linked at license.opensuse.org. Package warrants its
  own license
* Wed Mar 28 2012 idonmez@suse.com
- Initial release
